@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 ZNC, see the NOTICE file for details.
+ * Copyright (C) 2004-2015 ZNC, see the NOTICE file for details.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -24,6 +24,9 @@
 class CAdminLogMod : public CModule {
 public:
 	MODCONSTRUCTOR(CAdminLogMod) {
+		AddHelpCommand();
+		AddCommand("Show", static_cast<CModCommand::ModCmdFunc>(&CAdminLogMod::OnShowCommand), "", "Show the logging target");
+		AddCommand("Target", static_cast<CModCommand::ModCmdFunc>(&CAdminLogMod::OnTargetCommand), "<file|syslog|both>", "Set the logging target");
 		openlog("znc", LOG_PID, LOG_DAEMON);
 	}
 
@@ -32,7 +35,7 @@ public:
 		closelog();
 	}
 
-	virtual bool OnLoad(const CString & sArgs, CString & sMessage) {
+	virtual bool OnLoad(const CString & sArgs, CString & sMessage) override {
 		CString sTarget = GetNV("target");
 		if (sTarget.Equals("syslog"))
 			m_eLogMode = LOG_TO_SYSLOG;
@@ -49,36 +52,36 @@ public:
 		return true;
 	}
 
-	virtual void OnIRCConnected() {
-		Log("[" + m_pUser->GetUserName() + "/" + m_pNetwork->GetName() + "] connected to IRC: " + m_pNetwork->GetCurrentServer()->GetName());
+	virtual void OnIRCConnected() override {
+		Log("[" + GetUser()->GetUserName() + "/" + GetNetwork()->GetName() + "] connected to IRC: " + GetNetwork()->GetCurrentServer()->GetName());
 	}
 
-	virtual void OnIRCDisconnected() {
-		Log("[" + m_pUser->GetUserName() + "/" + m_pNetwork->GetName() + "] disconnected from IRC");
+	virtual void OnIRCDisconnected() override {
+		Log("[" + GetUser()->GetUserName() + "/" + GetNetwork()->GetName() + "] disconnected from IRC");
 	}
 
-	virtual EModRet OnRaw(CString& sLine) {
+	virtual EModRet OnRaw(CString& sLine) override {
 		if (sLine.Equals("ERROR ", false, 6)) {
 			//ERROR :Closing Link: nick[24.24.24.24] (Excess Flood)
 			//ERROR :Closing Link: nick[24.24.24.24] Killer (Local kill by Killer (reason))
 			CString sError(sLine.substr(6));
 			if (sError.Left(1) == ":")
 				sError.LeftChomp();
-			Log("[" + m_pUser->GetUserName() + "/" + m_pNetwork->GetName() + "] disconnected from IRC: " +
-			    m_pNetwork->GetCurrentServer()->GetName() + " [" + sError + "]", LOG_NOTICE);
+			Log("[" + GetUser()->GetUserName() + "/" + GetNetwork()->GetName() + "] disconnected from IRC: " +
+			    GetNetwork()->GetCurrentServer()->GetName() + " [" + sError + "]", LOG_NOTICE);
 		}
 		return CONTINUE;
         }
 
-	virtual void OnClientLogin() {
-		Log("[" + m_pUser->GetUserName() + "] connected to ZNC from " + m_pClient->GetRemoteIP());
+	virtual void OnClientLogin() override {
+		Log("[" + GetUser()->GetUserName() + "] connected to ZNC from " + GetClient()->GetRemoteIP());
 	}
 
-	virtual void OnClientDisconnect() {
-		Log("[" + m_pUser->GetUserName() + "] disconnected from ZNC from " + m_pClient->GetRemoteIP());
+	virtual void OnClientDisconnect() override {
+		Log("[" + GetUser()->GetUserName() + "] disconnected from ZNC from " + GetClient()->GetRemoteIP());
 	}
 
-	virtual void OnFailedLogin(const CString& sUsername, const CString& sRemoteIP) {
+	virtual void OnFailedLogin(const CString& sUsername, const CString& sRemoteIP) override {
 		Log("[" + sUsername + "] failed to login from " + sRemoteIP, LOG_WARNING);
 	}
 
@@ -104,62 +107,66 @@ public:
 		}
 	}
 
-	virtual void OnModCommand(const CString& sCommand) {
+	virtual void OnModCommand(const CString& sCommand) override {
 		if (!GetUser()->IsAdmin()) {
 			PutModule("Access denied");
+		} else {
+			HandleCommand(sCommand);
+		}
+	}
+
+	void OnTargetCommand(const CString& sCommand) {
+		CString sArg = sCommand.Token(1, true);
+		CString sTarget;
+		CString sMessage;
+		LogMode mode;
+
+		if (sArg.Equals("file")) {
+			sTarget = "file";
+			sMessage = "Now only logging to file";
+			mode = LOG_TO_FILE;
+		} else if (sArg.Equals("syslog")) {
+			sTarget = "syslog";
+			sMessage = "Now only logging to syslog";
+			mode = LOG_TO_SYSLOG;
+		} else if (sArg.Equals("both")) {
+			sTarget = "both";
+			sMessage = "Now logging to file and syslog";
+			mode = LOG_TO_BOTH;
+		} else {
+			if (sArg.empty()) {
+				PutModule("Usage: Target <file|syslog|both>");
+			} else {
+				PutModule("Unknown target");
+			}
 			return;
 		}
 
-		CString sCmd = sCommand.Token(0);
+		Log(sMessage);
+		SetNV("target", sTarget);
+		m_eLogMode = mode;
+		PutModule(sMessage);
+	}
 
-		if (sCmd.Equals("target")) {
-			CString sArg = sCommand.Token(1, true);
-			CString sTarget;
-			CString sMessage;
-			LogMode mode;
+	void OnShowCommand(const CString& sCommand) {
+		CString sTarget;
 
-			if (sArg.Equals("file")) {
-				sTarget = "file";
-				sMessage = "Now only logging to file";
-				mode = LOG_TO_FILE;
-			} else if (sArg.Equals("syslog")) {
-				sTarget = "syslog";
-				sMessage = "Now only logging to syslog";
-				mode = LOG_TO_SYSLOG;
-			} else if (sArg.Equals("both")) {
-				sTarget = "both";
-				sMessage = "Now logging to file and syslog";
-				mode = LOG_TO_BOTH;
-			} else {
-				PutModule("Unknown target");
-				return;
-			}
+		switch (m_eLogMode)
+		{
+		case LOG_TO_FILE:
+			sTarget = "file";
+			break;
+		case LOG_TO_SYSLOG:
+			sTarget = "syslog";
+			break;
+		case LOG_TO_BOTH:
+			sTarget = "both, file and syslog";
+			break;
+		}
 
-			Log(sMessage);
-			SetNV("target", sTarget);
-			m_eLogMode = mode;
-			PutModule(sMessage);
-		} else if (sCmd.Equals("show")) {
-			CString sTarget;
-
-			switch (m_eLogMode)
-			{
-			case LOG_TO_FILE:
-				sTarget = "file";
-				break;
-			case LOG_TO_SYSLOG:
-				sTarget = "syslog";
-				break;
-			case LOG_TO_BOTH:
-				sTarget = "both, file and syslog";
-				break;
-			}
-
-			PutModule("Logging is enabled for " + sTarget);
-			if (m_eLogMode != LOG_TO_SYSLOG)
-				PutModule("Log file will be written to [" + m_sLogFile + "]");
-		} else
-			PutModule("Commands: show, target <file|syslog|both>");
+		PutModule("Logging is enabled for " + sTarget);
+		if (m_eLogMode != LOG_TO_SYSLOG)
+			PutModule("Log file will be written to [" + m_sLogFile + "]");
 	}
 private:
 	enum LogMode {
