@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 ZNC, see the NOTICE file for details.
+ * Copyright (C) 2004-2015 ZNC, see the NOTICE file for details.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -77,25 +77,25 @@ public:
 
 	// Event stuff:
 
-	virtual void OnClientLogin() {
+	virtual void OnClientLogin() override {
 		SetTime(GetUser());
 	}
 
-	virtual void OnClientDisconnect() {
+	virtual void OnClientDisconnect() override {
 		SetTime(GetUser());
 	}
 
-	virtual EModRet OnDeleteUser(CUser& User) {
+	virtual EModRet OnDeleteUser(CUser& User) override {
 		DelNV(User.GetUserName());
 		return CONTINUE;
 	}
 
 	// Web stuff:
 
-	virtual bool WebRequiresAdmin() { return true; }
-	virtual CString GetWebMenuTitle() { return "Last Seen"; }
+	virtual bool WebRequiresAdmin() override { return true; }
+	virtual CString GetWebMenuTitle() override { return "Last Seen"; }
 
-	virtual bool OnWebRequest(CWebSock& WebSock, const CString& sPageName, CTemplate& Tmpl) {
+	virtual bool OnWebRequest(CWebSock& WebSock, const CString& sPageName, CTemplate& Tmpl) override {
 		if (sPageName == "index") {
 			CModules& GModules = CZNC::Get().GetModules();
 			Tmpl["WebAdminLoaded"] = CString(GModules.FindModule("webadmin") != NULL);
@@ -122,7 +122,7 @@ public:
 		return false;
 	}
 
-	virtual bool OnEmbeddedWebRequest(CWebSock& WebSock, const CString& sPageName, CTemplate& Tmpl) {
+	virtual bool OnEmbeddedWebRequest(CWebSock& WebSock, const CString& sPageName, CTemplate& Tmpl) override {
 		if (sPageName == "webadmin/user" && WebSock.GetSession()->IsAdmin()) {
 			CUser* pUser = CZNC::Get().FindUser(Tmpl["Username"]);
 			if (pUser) {
@@ -140,4 +140,4 @@ template<> void TModInfo<CLastSeenMod>(CModInfo& Info) {
 	Info.SetWikiPage("lastseen");
 }
 
-GLOBALMODULEDEFS(CLastSeenMod, "Collects data about when a user last logged in")
+GLOBALMODULEDEFS(CLastSeenMod, "Collects data about when a user last logged in.")
