@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 ZNC, see the NOTICE file for details.
+ * Copyright (C) 2004-2015 ZNC, see the NOTICE file for details.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -71,34 +71,33 @@ class CNotesMod : public CModule {
 
 public:
 	MODCONSTRUCTOR(CNotesMod) {
+		using std::placeholders::_1;
 		AddHelpCommand();
 		AddCommand("List",   static_cast<CModCommand::ModCmdFunc>(&CNotesMod::ListCommand));
 		AddCommand("Add",    static_cast<CModCommand::ModCmdFunc>(&CNotesMod::AddNoteCommand),
 			"<key> <note>");
 		AddCommand("Del",    static_cast<CModCommand::ModCmdFunc>(&CNotesMod::DelCommand),
 			"<key>",         "Delete a note");
-		AddCommand("Mod",    static_cast<CModCommand::ModCmdFunc>(&CNotesMod::ModCommand),
-			"<key> <note>",  "Modify a note");
-		AddCommand("Get",    static_cast<CModCommand::ModCmdFunc>(&CNotesMod::GetCommand),
-			"<key>");
+		AddCommand("Mod", "<key> <note>", "Modify a note", std::bind(&CNotesMod::ModCommand, this, _1));
+		AddCommand("Get", "<key>", "", [this](const CString& sLine){ GetCommand(sLine); });
 	}
 
 	virtual ~CNotesMod() {}
 
-	virtual bool OnLoad(const CString& sArgs, CString& sMessage) {
+	virtual bool OnLoad(const CString& sArgs, CString& sMessage) override {
 		bShowNotesOnLogin = !sArgs.Equals("-disableNotesOnLogin");
 		return true;
 	}
 
-	virtual CString GetWebMenuTitle() { return "Notes"; }
+	virtual CString GetWebMenuTitle() override { return "Notes"; }
 
-	virtual void OnClientLogin() {
+	virtual void OnClientLogin() override {
 		if (bShowNotesOnLogin) {
 			ListNotes(true);
 		}
 	}
 
-	virtual EModRet OnUserRaw(CString& sLine) {
+	virtual EModRet OnUserRaw(CString& sLine) override {
 		if (sLine.Left(1) != "#") {
 			return CONTINUE;
 		}
@@ -189,7 +188,7 @@ public:
 		}
 	}
 
-	virtual bool OnWebRequest(CWebSock& WebSock, const CString& sPageName, CTemplate& Tmpl) {
+	virtual bool OnWebRequest(CWebSock& WebSock, const CString& sPageName, CTemplate& Tmpl) override {
 		if (sPageName == "index") {
 			for (MCString::iterator it = BeginNV(); it != EndNV(); ++it) {
 				CTemplate& Row = Tmpl.AddRow("NotesLoop");
