@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 ZNC, see the NOTICE file for details.
+ * Copyright (C) 2004-2015 ZNC, see the NOTICE file for details.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -30,7 +30,7 @@ public:
 	MODCONSTRUCTOR(CQModule) {}
 	virtual ~CQModule() {}
 
-	virtual bool OnLoad(const CString& sArgs, CString& sMessage) {
+	virtual bool OnLoad(const CString& sArgs, CString& sMessage) override {
 		if (!sArgs.empty()) {
 			SetUsername(sArgs.Token(0));
 			SetPassword(sArgs.Token(1));
@@ -40,25 +40,49 @@ public:
 		}
 
 		CString sTmp;
-		m_bUseCloakedHost = (sTmp = GetNV("UseCloakedHost")).empty() ? true : sTmp.ToBool();
-		m_bUseChallenge   = (sTmp = GetNV("UseChallenge")).empty()  ? true : sTmp.ToBool();
-		m_bRequestPerms   = GetNV("RequestPerms").ToBool();
+		m_bUseCloakedHost   = (sTmp = GetNV("UseCloakedHost")).empty() ? true : sTmp.ToBool();
+		m_bUseChallenge     = (sTmp = GetNV("UseChallenge")).empty()  ? true : sTmp.ToBool();
+		m_bRequestPerms     = GetNV("RequestPerms").ToBool();
+		m_bJoinOnInvite     = (sTmp = GetNV("JoinOnInvite")).empty() ? true : sTmp.ToBool();
+		m_bJoinAfterCloaked = (sTmp = GetNV("JoinAfterCloaked")).empty() ? true : sTmp.ToBool();
+
+		// Make sure NVs are stored in config. Note: SetUseCloakedHost() is called further down.
+		SetUseChallenge(m_bUseChallenge);
+		SetRequestPerms(m_bRequestPerms);
+		SetJoinOnInvite(m_bJoinOnInvite);
+		SetJoinAfterCloaked(m_bJoinAfterCloaked);
 
 		OnIRCDisconnected(); // reset module's state
 
 		if (IsIRCConnected()) {
 			// check for usermode +x if we are already connected
-			set<unsigned char> scUserModes = m_pNetwork->GetIRCSock()->GetUserModes();
+			set<unsigned char> scUserModes = GetNetwork()->GetIRCSock()->GetUserModes();
 			if (scUserModes.find('x') != scUserModes.end())
 				m_bCloaked = true;
 
-			OnIRCConnected();
+			// This will only happen once, and only if the user loads the module after connecting to IRC.
+			// Also don't notify the user in case he already had mode +x set.
+			if (GetNV("UseCloakedHost").empty()) {
+				if (!m_bCloaked)
+					PutModule("Notice: Your host will be cloaked the next time you reconnect to IRC. "
+						"If you want to cloak your host now, /msg *q Cloak. You can set your preference "
+						"with /msg *q Set UseCloakedHost true/false.");
+				m_bUseCloakedHost = true;
+				SetUseCloakedHost(m_bUseCloakedHost);
+				m_bJoinAfterCloaked = true;
+				SetJoinAfterCloaked(m_bJoinAfterCloaked);
+			} else if (m_bUseChallenge) {
+				Cloak();
+			}
+			WhoAmI();
+		} else {
+			SetUseCloakedHost(m_bUseCloakedHost);
 		}
 
 		return true;
 	}
 
-	virtual void OnIRCDisconnected() {
+	virtual void OnIRCDisconnected() override {
 		m_bCloaked = false;
 		m_bAuthed  = false;
 		m_bRequestedWhoami    = false;
@@ -66,13 +90,13 @@ public:
 		m_bCatchResponse = false;
 	}
 
-	virtual void OnIRCConnected() {
+	virtual void OnIRCConnected() override {
 		if (m_bUseCloakedHost)
 			Cloak();
 		WhoAmI();
 	}
 
-	virtual void OnModCommand(const CString& sLine) {
+	virtual void OnModCommand(const CString& sLine) override {
 		CString sCommand = sLine.Token(0).AsLower();
 
 		if (sCommand == "help") {
@@ -125,6 +149,14 @@ public:
 			Table2.SetCell("Setting", "RequestPerms");
 			Table2.SetCell("Type", "Boolean");
 			Table2.SetCell("Description", "Whether to request voice/op from Q on join/devoice/deop.");
+			Table2.AddRow();
+			Table2.SetCell("Setting", "JoinOnInvite");
+			Table2.SetCell("Type", "Boolean");
+			Table2.SetCell("Description", "Whether to join channels when Q invites you.");
+			Table2.AddRow();
+			Table2.SetCell("Setting", "JoinAfterCloaked");
+			Table2.SetCell("Type", "Boolean");
+			Table2.SetCell("Description", "Whether to delay joining channels until after you are cloaked.");
 			PutModule(Table2);
 
 			PutModule("This module takes 2 optional parameters: <username> <password>");
@@ -144,14 +176,18 @@ public:
 			} else if (sSetting == "usecloakedhost") {
 				SetUseCloakedHost(sValue.ToBool());
 				PutModule("UseCloakedHost set");
-				if (m_bUseCloakedHost && IsIRCConnected())
-					Cloak();
 			} else if (sSetting == "usechallenge") {
 				SetUseChallenge(sValue.ToBool());
 				PutModule("UseChallenge set");
 			} else if (sSetting == "requestperms") {
 				SetRequestPerms(sValue.ToBool());
 				PutModule("RequestPerms set");
+			} else if (sSetting == "joinoninvite") {
+				SetJoinOnInvite(sValue.ToBool());
+				PutModule("JoinOnInvite set");
+			} else if (sSetting == "joinaftercloaked") {
+				SetJoinAfterCloaked(sValue.ToBool());
+				PutModule("JoinAfterCloaked set");
 			} else
 				PutModule("Unknown setting: " + sSetting);
 
@@ -174,6 +210,12 @@ public:
 			Table.AddRow();
 			Table.SetCell("Setting", "RequestPerms");
 			Table.SetCell("Value", CString(m_bRequestPerms));
+			Table.AddRow();
+			Table.SetCell("Setting", "JoinOnInvite");
+			Table.SetCell("Value", CString(m_bJoinOnInvite));
+			Table.AddRow();
+			Table.SetCell("Setting", "JoinAfterCloaked");
+			Table.SetCell("Value", CString(m_bJoinAfterCloaked));
 			PutModule(Table);
 
 		} else if (sCommand == "status") {
@@ -210,38 +252,124 @@ public:
 		}
 	}
 
-	virtual EModRet OnRaw(CString& sLine) {
+	virtual EModRet OnRaw(CString& sLine) override {
 		// use OnRaw because OnUserMode is not defined (yet?)
 		if (sLine.Token(1) == "396" && sLine.Token(3).find("users.quakenet.org") != CString::npos) {
 			m_bCloaked = true;
 			PutModule("Cloak successful: Your hostname is now cloaked.");
+
+			// Join channels immediately after our spoof is set, but only if
+			// both UseCloakedHost and JoinAfterCloaked is enabled. See #602.
+			if (m_bJoinAfterCloaked) {
+				GetNetwork()->JoinChans();
+			}
 		}
 		return CONTINUE;
 	}
 
-	virtual EModRet OnPrivMsg(CNick& Nick, CString& sMessage) {
+	virtual EModRet OnPrivMsg(CNick& Nick, CString& sMessage) override {
 		return HandleMessage(Nick, sMessage);
 	}
 
-	virtual EModRet OnPrivNotice(CNick& Nick, CString& sMessage) {
+	virtual EModRet OnPrivNotice(CNick& Nick, CString& sMessage) override {
 		return HandleMessage(Nick, sMessage);
 	}
 
-	virtual void OnJoin(const CNick& Nick, CChan& Channel) {
+	virtual EModRet OnJoining(CChan& Channel) override {
+		// Halt if are not already cloaked, but the user requres that we delay
+		// channel join till after we are cloaked.
+		if (!m_bCloaked && m_bUseCloakedHost && m_bJoinAfterCloaked)
+			return HALT;
+
+		return CONTINUE;
+	}
+
+	virtual void OnJoin(const CNick& Nick, CChan& Channel) override {
 		if (m_bRequestPerms && IsSelf(Nick))
 			HandleNeed(Channel, "ov");
 	}
 
-	virtual void OnDeop(const CNick& OpNick, const CNick& Nick, CChan& Channel, bool bNoChange) {
-		if (m_bRequestPerms && IsSelf(Nick) && !IsSelf(OpNick))
+	virtual void OnDeop2(const CNick* pOpNick, const CNick& Nick, CChan& Channel, bool bNoChange) override {
+		if (m_bRequestPerms && IsSelf(Nick) && (!pOpNick || !IsSelf(*pOpNick)))
 			HandleNeed(Channel, "o");
 	}
 
-	virtual void OnDevoice(const CNick& OpNick, const CNick& Nick, CChan& Channel, bool bNoChange) {
-		if (m_bRequestPerms && IsSelf(Nick) && !IsSelf(OpNick))
+	virtual void OnDevoice2(const CNick* pOpNick, const CNick& Nick, CChan& Channel, bool bNoChange) override {
+		if (m_bRequestPerms && IsSelf(Nick) && (!pOpNick || !IsSelf(*pOpNick)))
 			HandleNeed(Channel, "v");
 	}
 
+	virtual EModRet OnInvite(const CNick& Nick, const CString& sChan) override {
+		if (!Nick.NickEquals("Q") || !Nick.GetHost().Equals("CServe.quakenet.org"))
+			return CONTINUE;
+		if (m_bJoinOnInvite)
+			GetNetwork()->AddChan(sChan, false);
+		return CONTINUE;
+	}
+
+	virtual CString GetWebMenuTitle() override { return "Q"; }
+
+	virtual bool OnWebRequest(CWebSock& WebSock, const CString& sPageName, CTemplate& Tmpl) override {
+		if (sPageName == "index") {
+			bool bSubmitted = (WebSock.GetParam("submitted").ToInt() != 0);
+
+			if (bSubmitted) {
+				CString FormUsername = WebSock.GetParam("user");
+				if (!FormUsername.empty())
+					SetUsername(FormUsername);
+
+				CString FormPassword = WebSock.GetParam("password");
+				if (!FormPassword.empty())
+					SetPassword(FormPassword);
+
+				SetUseCloakedHost(WebSock.GetParam("usecloakedhost").ToBool());
+				SetUseChallenge(WebSock.GetParam("usechallenge").ToBool());
+				SetRequestPerms(WebSock.GetParam("requestperms").ToBool());
+				SetJoinOnInvite(WebSock.GetParam("joinoninvite").ToBool());
+				SetJoinAfterCloaked(WebSock.GetParam("joinaftercloaked").ToBool());
+			}
+
+			Tmpl["Username"] = m_sUsername;
+
+			CTemplate& o1 = Tmpl.AddRow("OptionLoop");
+			o1["Name"] = "usecloakedhost";
+			o1["DisplayName"] = "UseCloakedHost";
+			o1["Tooltip"] = "Whether to cloak your hostname (+x) automatically on connect.";
+			o1["Checked"] = CString(m_bUseCloakedHost);
+
+			CTemplate& o2 = Tmpl.AddRow("OptionLoop");
+			o2["Name"] = "usechallenge";
+			o2["DisplayName"] = "UseChallenge";
+			o2["Tooltip"] = "Whether to use the CHALLENGEAUTH mechanism to avoid sending passwords in cleartext.";
+			o2["Checked"] = CString(m_bUseChallenge);
+
+			CTemplate& o3 = Tmpl.AddRow("OptionLoop");
+			o3["Name"] = "requestperms";
+			o3["DisplayName"] = "RequestPerms";
+			o3["Tooltip"] = "Whether to request voice/op from Q on join/devoice/deop.";
+			o3["Checked"] = CString(m_bRequestPerms);
+
+			CTemplate& o4 = Tmpl.AddRow("OptionLoop");
+			o4["Name"] = "joinoninvite";
+			o4["DisplayName"] = "JoinOnInvite";
+			o4["Tooltip"] = "Whether to join channels when Q invites you.";
+			o4["Checked"] = CString(m_bJoinOnInvite);
+
+			CTemplate& o5 = Tmpl.AddRow("OptionLoop");
+			o5["Name"] = "joinaftercloaked";
+			o5["DisplayName"] = "JoinAfterCloaked";
+			o5["Tooltip"] = "Whether to delay joining channels until after you are cloaked.";
+			o5["Checked"] = CString(m_bJoinAfterCloaked);
+
+			if (bSubmitted) {
+				WebSock.GetSession()->AddSuccess("Changes have been saved!");
+			}
+
+			return true;
+		}
+
+		return false;
+	}
 
 private:
 	bool m_bCloaked;
@@ -263,7 +391,7 @@ private:
 			return;
 
 		PutModule("Cloak: Trying to cloak your hostname, setting +x...");
-		PutIRC("MODE " + m_pNetwork->GetIRCSock()->GetNick() + " +x");
+		PutIRC("MODE " + GetNetwork()->GetIRCSock()->GetNick() + " +x");
 	}
 
 	void WhoAmI() {
@@ -303,12 +431,12 @@ private:
 		                                   .Replace_n("[",  "{")
 		                                   .Replace_n("]",  "}")
 		                                   .Replace_n("\\", "|");
-		CString sPasswordHash = m_sPassword.Left(10).MD5();
-		CString sKey          = CString(sUsername + ":" + sPasswordHash).MD5();
-		CString sResponse     = HMAC_MD5(sKey, sChallenge);
+		CString sPasswordHash = m_sPassword.Left(10).SHA256();
+		CString sKey          = CString(sUsername + ":" + sPasswordHash).SHA256();
+		CString sResponse     = HMAC_SHA256(sKey, sChallenge);
 
 		PutModule("Auth: Received challenge, sending CHALLENGEAUTH request...");
-		PutQ("CHALLENGEAUTH " + m_sUsername + " " + sResponse + " HMAC-MD5");
+		PutQ("CHALLENGEAUTH " + m_sUsername + " " + sResponse + " HMAC-SHA-256");
 	}
 
 	EModRet HandleMessage(const CNick& Nick, CString sMessage) {
@@ -362,10 +490,10 @@ private:
 			if (sMessage.find("not available once you have authed") != CString::npos) {
 				m_bAuthed = true;
 			} else {
-				if (sMessage.find("HMAC-MD5") != CString::npos) {
+				if (sMessage.find("HMAC-SHA-256") != CString::npos) {
 					ChallengeAuth(sMessage.Token(1));
 				} else {
-					PutModule("Auth failed: Q does not support HMAC-MD5 for CHALLENGEAUTH, falling back to standard AUTH.");
+					PutModule("Auth failed: Q does not support HMAC-SHA-256 for CHALLENGEAUTH, falling back to standard AUTH.");
 					SetUseChallenge(false);
 					Auth();
 				}
@@ -413,12 +541,12 @@ private:
 
 /* Utility Functions */
 	bool IsIRCConnected() {
-		CIRCSock* pIRCSock = m_pNetwork->GetIRCSock();
+		CIRCSock* pIRCSock = GetNetwork()->GetIRCSock();
 		return pIRCSock && pIRCSock->IsAuthed();
 	}
 
 	bool IsSelf(const CNick& Nick) {
-		return Nick.NickEquals(m_pNetwork->GetCurNick());
+		return Nick.NickEquals(GetNetwork()->GetCurNick());
 	}
 
 	bool PackHex(const CString& sHex, CString& sPackedHex) {
@@ -439,10 +567,10 @@ private:
 		return true;
 	}
 
-	CString HMAC_MD5(const CString& sKey, const CString& sData) {
+	CString HMAC_SHA256(const CString& sKey, const CString& sData) {
 		CString sRealKey;
 		if (sKey.length() > 64)
-			PackHex(sKey.MD5(), sRealKey);
+			PackHex(sKey.SHA256(), sRealKey);
 		else
 			sRealKey = sKey;
 
@@ -455,8 +583,8 @@ private:
 		}
 
 		CString sInnerHash;
-		PackHex(CString(sInnerKey + sData).MD5(), sInnerHash);
-		return CString(sOuterKey + sInnerHash).MD5();
+		PackHex(CString(sInnerKey + sData).SHA256(), sInnerHash);
+		return CString(sOuterKey + sInnerHash).SHA256();
 	}
 
 /* Settings */
@@ -465,6 +593,8 @@ private:
 	bool    m_bUseCloakedHost;
 	bool    m_bUseChallenge;
 	bool    m_bRequestPerms;
+	bool    m_bJoinOnInvite;
+	bool    m_bJoinAfterCloaked;
 
 	void SetUsername(const CString& sUsername) {
 		m_sUsername = sUsername;
@@ -479,6 +609,9 @@ private:
 	void SetUseCloakedHost(const bool bUseCloakedHost) {
 		m_bUseCloakedHost = bUseCloakedHost;
 		SetNV("UseCloakedHost", CString(bUseCloakedHost));
+
+		if (!m_bCloaked && m_bUseCloakedHost && IsIRCConnected())
+			Cloak();
 	}
 
 	void SetUseChallenge(const bool bUseChallenge) {
@@ -490,6 +623,16 @@ private:
 		m_bRequestPerms = bRequestPerms;
 		SetNV("RequestPerms", CString(bRequestPerms));
 	}
+
+	void SetJoinOnInvite(const bool bJoinOnInvite) {
+		m_bJoinOnInvite = bJoinOnInvite;
+		SetNV("JoinOnInvite", CString(bJoinOnInvite));
+	}
+
+	void SetJoinAfterCloaked(const bool bJoinAfterCloaked) {
+		m_bJoinAfterCloaked = bJoinAfterCloaked;
+		SetNV("JoinAfterCloaked", CString(bJoinAfterCloaked));
+	}
 };
 
 template<> void TModInfo<CQModule>(CModInfo& Info) {
